﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

[RequireComponent(typeof(Camera))]
public class CameraInterpolator : MonoBehaviour
{
  public Camera from;
  public Camera to;
  [Range(0, 1)]
  public float t = 0;

  private Camera target;

  public void Awake()
  {
    target = GetComponent<Camera>();
  }

  private void OnPreRender()
  {
    //projection
    var pa = from.nonJitteredProjectionMatrix;
    var pb = to.nonJitteredProjectionMatrix;
    var p = LerpMatrix(pa, pb, t);

    target.ResetProjectionMatrix();
    target.ResetProjectionMatrix();
    target.nonJitteredProjectionMatrix = p;

    //world
    var wa = from.worldToCameraMatrix;
    var wb = to.worldToCameraMatrix;
    var w = LerpMatrix(wa, wb, t);

    target.ResetWorldToCameraMatrix();
    target.ResetWorldToCameraMatrix();
    target.worldToCameraMatrix = w;

    target.orthographic = t < 0.5f ? from.orthographic : to.orthographic;
    target.orthographicSize = t < 0.5f ? from.orthographicSize : to.orthographicSize;
  }

  private Matrix4x4 LerpMatrix(Matrix4x4 a, Matrix4x4 b, float t)
  {
    Matrix4x4 ret = new Matrix4x4();
    for (int i = 0; i < 16; i++)
      ret[i] = Mathf.Lerp(a[i], b[i], t);
    return ret;
  }

  public void OnGUI()
  {
    t = GUI.HorizontalSlider(new Rect(250, 10, 100, 30), t, 0.0F, 1.0F);
  }
}
