﻿using Mapbox.Unity.Map;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using Mapbox.Unity.Utilities;
using Mapbox.Utils;
using System;

public class PathPicker : MonoBehaviour
{
  public AbstractMap map;
  public Camera mainCamera;
  public DataPointVisualize dataPointVisualize;
  public float selectedLineRendererThickness = 3;

  private LineRenderer lastLineRender = null;
  private float lastLineRenderWidth;

  public void Update()
  {
    if (Input.GetMouseButtonDown(0)) {
      ProcessClick();
    }
  }
  private void pickPath(Vector2d geo)
  {
    double distances = Double.MaxValue;
    DataPath closestPath = null;

    Debug.Log(dataPointVisualize.Paths);
    foreach (var path in dataPointVisualize.Paths)
    {
      foreach (var point in path.points)
      {
        Vector2d p = new Vector2d(point.lat, point.lon);

        var div = geo - p;
        var mag = div.sqrMagnitude;

        if (mag < distances) {
          distances = mag;
          closestPath = path;
        }
      }
    }

    if (closestPath != null)
    {
      Debug.Log(closestPath.id_hash);
      var lr = closestPath.GetComponent<LineRenderer>();

      if (lastLineRender) {
        lastLineRender.startWidth = lastLineRenderWidth;
        lastLineRender.endWidth = lastLineRenderWidth;
      }

      lastLineRender = lr;
      lastLineRenderWidth = lr.startWidth;

      lr.startWidth = selectedLineRendererThickness;
      lr.endWidth = selectedLineRendererThickness;
    }
  }

  public void ProcessClick()
  {
    var mp = Input.mousePosition;
    var ray = mainCamera.ScreenPointToRay(mp);

    RaycastHit hit;
    if (Physics.Raycast(ray, out hit)) {
      var p = hit.point;

      Debug.Log(mp.ToString());
      Debug.Log(p.ToString());

      var geo = p.GetGeoPosition(map.CenterMercator, map.WorldRelativeScale);
      Debug.Log(geo.ToString());

      pickPath(geo);
    }
  }
}
